---
title: "Book Review: The Art of the Argument"
date: 2018-05-29T22:19:42Z
tags: ["reviews","pop philosophy","rhetoric","sophistry"]
topics: ["philosophy"]
image: /img/art-of-the-argument.jpg
draft: false
---

This weekend I had a little extra time on my hands, because of the bank holiday. It’s been quite a while since I’ve looked at any work by the growing cadre of freelance internet philosophers. So, I decided to have a look at the latest offering by Stefan Molyneux. Not a man to shy away from dramatic overstatement, the book is titled, [The Art of The Argument: Civilization’s Last Stand](https://www.amazon.com/Art-Argument-Western-Civilizations-Stand-ebook/dp/B0756QYZ26).

The basic thesis of the book is that “sophists” – described as those who manipulate language and appeal to emotion to gain power for themselves – are undermining the basic capacity for good people to negotiate terms amongst themselves in good faith, and that without this capacity to engage in rational debate, civilization itself will descend into a chaos of brute force misery and destruction. He has taken it to be his task, then, to recruit and educate the new generation of soldiers in the war of the rational against the “relativist” and the “sophist”, and to train them up in the art of ***The Argument\***.

Some have confused the purpose of this book, because of it’s title. Several reviewers on Amazon took it to be an attempt at a layman-accessible textbook or tutorial, and have [heavily critiqued the book](https://www.amazon.co.uk/gp/customer-reviews/R29YVREE2ZBQ1H/ref=cm_cr_arp_d_rvw_ttl?ie=UTF8&ASIN=B0756QYZ26) in ways that, though largely correct, are far too stringent for a polemical tract of this kind, and fall directly into the trap Stefan sets for them, in his preface (hilariously titled “Trigger Warning”):

> ’The Art of the Argument’ is an outright battle manual, not a prissy abstract academic paper… As we approach Western Civilization’s last stand for survival, loftily lecturing people on arcane terms is a mere confession of pitiful impotence…

That ought to give some context as to what to actually expect from this book. Stefan thinks he’s distributing a basic survival manual in a state of impending cultural apocalypse (cue the picture of Patton standing in front of the flag). What of those who actually care to be precise, methodical, and try to practice a little epistemic humility? Well, Stefan just thinks they’re “whining”, and “*turning logic into wingdings*”.

### I Am Absolutely Certain

Still, precision and clarity is precisely what one would *want* if one were arming people for an ‘intellectual battle’, and it is true that his explanations of deduction and induction are rushed straw-men that, at times, are incoherent or just plain wrong. He is telling readers that he is equipping them with broad-swords, but handing them broom handles instead. We’ll get to examples of all this shortly, but first, a note about Stefan’s main object of un-ironic attention in the first part of the book: *absolute certainty*. Unlike most of us, who’ve come to understand that such a thing probably doesn’t exist, and that believing one has obtained such a thing is dangerous to the point of precipitating wars and genocides, Stefan on the other hand, has come to see absolute certainty as a special place one can go, to escape the “relativists”:

> if you surrender to the peace of absolutism – if the premises are correct, and the reasoning is correct, the conclusion is absolute and inescapable – you will quickly find it a beautiful place to be, and that relativists are trying to deny you the peace, Zen, and beauty of the paradise called certainty.

Rather than understanding, or self-knowledge (something he used to talk a lot about), or curiosity, or mindfulness, it is the *absolute certainty* of deductive rigor that will get his readers to the truth, and it is *absolute certainty* that will make his readers the *winners* of ***The Argument\***.

It is this fixation that sets the tone for the opening explication of deductive and inductive reasoning. He rightly describes inductive reasoning as the method of reasoning to probabilities, and deductive reasoning as the method of reasoning to certainties. But because certainty is king, inductive reasoning plays only a secondary submissive role in Stefan’s jungle story known as the ***The Argument\***, and he equates probabilistic thinking simply with ‘rank relativism’:

> A predator must be absolute in its reasoning. The lion must correctly identify and stalk the zebra, must calculate speed and interception without error, must attack and bite accurately, and must persist until the prey is down. All this must serve the conclusion: the meal. However, prey has a different set of calculations because a predator can see the prey, but the prey usually cannot see the predator – at least until it is too late… Dominant life forms revel in absolutes and fight hard against any encroaching fumes of **rank relativism**. A tiger cannot hunt if it doubts the evidence of its senses. The life of a zebra is a life of doubt, of fear. [emphasis added]

This zeal for *absolute certainty* traps him in something of a bind later. When describing the scientific method, he has to characterize it as *fundamentally* deductive:

> The Scientific Method is absolute – deductive – but individual hypotheses are usually conditional… inductive reasoning must be subject to the absolutes of deductive reasoning…

While it’s true that deductive reasoning plays a significant role in evaluating hypotheses and the research products of scientific disciplines, it is wrong to assert that deduction is a primary in all cases. Deduction and induction play complementary roles in the methods of science, and which has primacy depends on the method and the context (though, for Stefan, The Scientific Method is just one thing).

Stefan says, “*All valid hypotheses must conform with – and predict – empirical observations*“. Embedded implicitly in this assertion, is an idea never explicitly referenced, but clearly implied by his rhetoric about the scientific method. He wants to use Popperian falsificationism as a proxy for deductive certainty. While its true that Popper sought a way to give scientific conclusions a certainty akin to those of deductive arguments, he would never have pretended that falsification was *equivalent* to deductive certainty. The point was not to inject the absolutism of Augustinian faith declarations into scientific conclusions. Rather, it was to reduce the potential for catastrophic error – a brick wall into which Molyneux seems determined to drive himself. All of this effort comes on the heals of labeling deductive reasoning “alpha”, and inductive reasoning “beta”. He needed a way to rescue sissy science from the beta-cuck basement; and the way he does it, is by making it the twee Robin beside the manly Batman of deduction.

But why is *absolute certainty* so important to Stefan? Because, for him, no rational action is possible without it:

> The lion stalking the zebra is engaged in proactive behavior, and thus, by initiating the encounter, is in far greater control of the variables… Initiating action requires the certainty of deductive reasoning, and control over variables increases that certainty… The pursuit of the lion is the initiating action, the flight of the zebra is the reaction.

Deductive lions are proactive, and inductive zebras are reactive. Neither act at all, without having achieved the *absolute certainty* of empirical verification. But is this actually how we act? I would argue that it is not. There are many things we do, day to day, without the absolute certainty of a deductive conclusion. In fact, most things we do are this way. He offers the example of deciding to bring an umbrella. But one could easily imagine deciding which arguments to deploy in a debate as well. The fascination with certainty also seems to run counter to Stefan’s commitment to free will, as well. The kind of certainty he describes could easily be imagined as the kind of certainty that results in perfect prediction (something akin to what he says above about hypotheses). Does this not imply some sort of threshold determinism? Given this, why, if I were an adherent of some common-sense conception of the free will, would I want to believe this was the only way I could act? Buried in this fixation, is the need to be *morally justified*, in order to act. For Stefan, acting without certainty is acting without the necessary moral authority. To act instead, as most of us do, on varying degrees of confidence in beliefs, is moral corruption. He needs to be certain, because he needs to *be good*. If I am *absolutely certain*, then your condemnations of me are like arrows bouncing off a tank.

### What’s ***The Argument\***?

In addition to the poor analogy to lions and zebras, and the failure to provide a stable definition of truth (or ‘virtue’, or ‘happiness’, or a half-dozen other things) Stefan never takes the time to explain what propositions are, or what makes them a proper part of an argument. This, to me, seems like it would not be too big a leap of effort, even for his readers. Clearly, he knows what they are, because he provides lots of them in this book. But he is terribly inconsistent about it. At one point, late in the book, he even seems to confuse validity and truth, and incorrectly marks out a single proposition as an argument:

> ‘Ice cream contains dairy’ is an argument, since it claims to describe a property objectively measurable and testable…

Being “objectively measurable and testable” does not meet the definition of an argument by even the most rudimentary general definition, as a ‘collection of reasons supporting a conclusion’. What’s worse, it doesn’t even meet Stefan’s own initial definition, as being:

> an attempt to convince another person of the truth or value of your position using only reason and evidence.

All we have here, is an asserted conclusion in the form of a subject-predicate proposition. There are no reasons supporting it, and no evidence offered to ‘verify’ it’s ‘objective reality’. Even if we take the colloquial presumptions, and accept that the subject ‘ice cream’ does refer to something in reality, and that the predicate ‘contains dairy’ accurately modifies this subject with – as he puts it – “*a property objectively measurable and testable*”, it still remains that a measurement must be made, and the result of that added to this proposition, *in order to make it an argument*. So, perhaps something like:

1. Ice cream is made with milk
2. Milk is a dairy product
3. Therefore, ice cream contains dairy

Note that this is a standard example of the [transitive property](https://www.britannica.com/topic/transitive-law) applied to the propositions of a logical argument. If Stefan were trying to outfit his army with a sharp argumentative blade, then this was definitely a missed opportunity.

A bit later, he wants to say that *’inequality is bad’* is not an argument, and he tries to sustain this claim by way of this newly minted definition of an argument (its needing to be “objectively measurable and testable”). But rather than argue that “bad” is not “objectively measurable”, which would be the obvious thing to do given the new definition, he says this is because “bad” is a false-substitute for a preference claim, e.g., “I don’t like inequality”. But this only makes his explanation inscrutable. Surely, I can objectively measure a man’s preferences. Even if we reject self-reporting as acceptable, one could still measure pleasure responses neurologically, to obtain the truth of his statement, and in doing so, show that “bad” is an acceptable substitute for “dislike”.

But it turns out that’s not why Molyneux makes this turn in the story. Instead, he wants to lodge an entirely new complaint about how personal preference isn’t a reasonable standard for moral judgment. On this point, I might be in agreement (were I to see an argument), but the problem is that it’s not germane to the explanation of *what is and is not an argument*. He’s lost visibility of the *form* of his argument, because he’s utterly distracted by the *content*. Perhaps those “*wingdings*” would come in handy about now?

### Getting An Ought From An Ought…

Now, we move beyond the logic lessons, and on to some specific content problems with this book. There are dozens of inaccuracies, exaggerations, and hyperbolic misreadings to be found littered across the pages of this book. I am going to focus on just three instances. First on the list (the most challenging to untangle) is his ham-fisted attempt at a refutation of Hume’s Is-Ought dichotomy. He states Hume’s case this way:

> David Hume, the famous Scottish philosopher… introduc[ed] the concept of Humean scepticism, or the idea that you cannot get an “ought” from an “is.” While it is true that cutting off a man’s head will kill him, there is nothing in the basic biology that tells us we ought not to do it: in other words, there is no morality in physics.

This is a common simplification of the is-ought dichotomy, and it suffers from the common problem of misunderstanding Hume’s logic problem as a reification problem (that “moral” properties are “real”). His rebuttal to this formulation amounts to two objections. First, predictably, that the is-ought problem is a non-problem (“irrelevant”, in his words):

> There is no such thing as logic in material physics either, but we do not think that logic is unnecessary or irrelevant or subjective.

This argument fails, because it doesn’t actually prove the case of irrelevance. Rather, he beats down the straw-man of reification. There is no “logic in material physics” (by which, he means ‘physical reality’), because logic (loosely speaking) is a set of rules defining a means of *describing* certain features of physical matter (as in, Aristotle’s three laws). Likewise, there is no “morality in material physics”, because morality (loosely speaking) is a set of rules defining a means of *evaluating* certain features of human character and behavior. The problem is to be found not in where any properties lie, but in the two words I highlighted: “describing” and “evaluating”, and their usage in arguments. Molyneux is aware of this difference. It is a key component of his opening claims about arguments. We’ll recall, that there are two kinds, according to him:

> Truth arguments aim to unite fragmented and subjective humanity under the challenging banner of actual reality… Value arguments aim at improvements in aesthetic or moral standards… A truth argument can tell us who killed someone. A value argument tells us that murder is wrong.

So, it’s clear that we have two different categories of argumentation, and that they need to be accounted for independently (indeed, justified independently), and reconciled. Which gets us to Stefan’s second objection:

> …considering Hume’s argument that you cannot get an “ought” from an “is,” we can easily see that the mirror of **The Argument** destroys **The Argument**. If we cannot get an “ought” from an “is,” then anyone who tries to argue that we can is wrong. In other words, we “ought not” get an “ought” from an “is.” Arguing that we cannot derive universally preferable behavior from mere matter and energy argues that it is universally preferable behavior to not derive an “ought” from an “is.” If we cannot derive an “ought” from an “is,” this means that we can derive an “ought” from an “is,” which is that we ought not try it: a self detonating argument.

There are two major problems with this argument. First, contrary to popular misconception, Hume never actually asserted that one cannot not derive an ought from an is. Second, Molyneux is exemplifying in his prose, precisely the problem that Hume was actually describing in his Treatise. Let’s take a look at Hume’s actual words:

> In every system of morality, which I have hitherto met with, I have always remarked, that the author proceeds for some time in the ordinary way of reasoning, and establishes the being of a God, or makes observations concerning human affairs; when of a sudden I am surprized to find, that instead of the usual copulations of propositions, is, and is not, I meet with no proposition that is not connected with an ought, or an ought not. This change is imperceptible; but is, however, of the last consequence. **For as this ought, or ought not, expresses some new relation or affirmation, it is necessary that it should be observed and explained;** and at the same time that a reason should be given, for what seems altogether inconceivable, how this new relation can be a deduction from others, which are entirely different from it. (Treatise 3.1.1)

This may seem too subtle for a general overview, but Hume is not saying you “cannot derive an ought from an is”. He’s saying exactly what I said above: there appears to be two categorically different kinds of reasoning, and authors are mixing them in their writings, without explaining how the relations work. The relation is simply assumed, without justification. That is a problem that is hardly irrelevant to philosophy. Here is a rudimentary example:

1. Some humans go hungry in winter
2. Those with food ought to feed the hungry in winter

Just like Stefan’s example of murder above, we have one proposition that is in the ‘descriptive’ category, and one that is in the ‘evaluative’ category (or, in this case, injunctive which – loosely speaking – implies normative evaluation). By what laws of logic can the second proposition be transformed into a conclusion from the first? Or, at lease, how can we show logical linkage between proposition 1 and proposition 2? That is what Hume was asking his reader to consider. In order for Hume to sustain the broader positive assertion that “one cannot derive an ought from an is”, he would’ve had to construct a theory of deduction that categorically (and absolutely, ironically) excluded evaluation statements or injunctions as meaningful propositions (in the true/false sense of meaning). He didn’t do that.

But what of Stefan’s clever turn? If we take the colloquial assertion as read (regardless of what Hume was saying), does Molyneux successfully refute it? I still don’t think so. First, note his usage of the word “wrong” in that passage:

> If we cannot get an “ought” from an “is,” then anyone who tries to argue that we can is wrong.

Does he mean “incorrect”, or does he mean “bad”? Fortunately, Molyneux provides a clarification:

> In other words, we “ought not” get an “ought” from an “is.”

Is saying that we cannot derive an ought from an is, the same as saying we *ought not* derive an ought from an is (i.e., that it would be ‘bad’ for us to do this)? On broad broad reading, Molyneux may have a point. The rules of logic are often described as normative as well as descriptive (see [Guttenplan](https://www.amazon.co.uk/Languages-Logic-Introduction-Formal/dp/155786988X), for example). In other words, the rules ‘guide good behavior’ in argumentation, in some sense, in addition to simply describing the methods of thinking. But that’s not what’s going on here. As I pointed out above, nobody is saying that it is *morally wrong* to derive an ought from an is, merely that it doesn’t seem possible, given the present theories of logic available to us. The task would be to build a logical system that incorporated normative evaluation and injunction into the system (in other words, to somehow provide a truth-bearing meaning for those sorts of statements). Not an easy task, but also not necessarily an impossibility.

In any case, to make this objection stick, and condemn the dichotomy, Stefan has to appeal to his own moral theory (known as “Universally Preferred Behavior”):

> Arguing that we cannot derive universally preferable behavior from mere matter and energy argues that it is universally preferable behavior to not derive an “ought” from an “is.” If we cannot derive an “ought” from an “is,” this means that we can derive an “ought” from an “is,” which is that we ought not try it: a self detonating argument.

This should raise a red flag. Because, again, Hume isn’t making a moral condemnation of the traversal from descriptive to normative. He’s asking how it’s possible to do so in moral theories, given the normal rules of logic. What’s more, even if we granted the *normative* complaint, it’s still a stretch to say that all normative evaluations are *moral* evaluations, and therefore, must be held to the same definitional standard – and in doing so, ruling out moral complaints about evaluative language in logic. In other words, to make the objection from UPB work, Stefan has to commit exactly the same sleight of hand that Hume was complaining about: “ *instead of the usual copulations of propositions, is, and is not, I meet with no proposition that is not connected with an ought, or an ought not*”.

### Democracy Is For Dummies

The second example is a straw man the size of the Wicker Man. For a man with both a BA and an MA in history, I am continually in awe of Stefan’s utter disregard and contempt for it. Often, he actually seems proud of the contempt he sprinkles liberally throughout this book. One breathtaking example of these random turds can be found here:

> Less intelligent people invented democracy (more intelligent people invented Republics), because, being less intelligent, they could not influence society through the brilliance of their writing and oratory. But naturally they wish to have such influence, and therefore invented the concept of “one adult, one vote.” This makes their political perspectives equally valuable to the greatest genius in the land. In other words, they get the effects of genius, without the genetics or hard work of becoming a genius. From an amoral, biological standpoint, who can blame them?

Setting aside the comparative confusion (“less intelligent” than whom? “more intelligent” than what?), I have to wonder why this was even included in the book. It’s one of the most cartoonishly ignorant and cynical descriptions of the invention of democracy I’ve ever read (and I’ve read some bad ones). But, let’s entertain the possibility, for the moment. Is it reasonable to suppose that Solon, Cleisthenes, and Ephialtes were indeed low-IQ, genetically inferior parasites who, unable to “*influence society through the brilliance of their writing and oratory*”, still somehow managed to convince the population of Athens over a generation, to divide themselves into classes, and organize themselves around a complex system of representative bodies like the Ecclesia, the Boule, and the Areopagus? In a book touting the power of ***The Argument\***, dare I ask for ***An Argument\*** for this claim? What would such an argument look like? What sort of society would have replaced early Greek democracy, had these intellectual inferiors not succeeded to transform their society? Stefan doesn’t bother to elaborate. Rather, he wants this assertion to stand on its own, as a stepping-stone in a chain of shallow reasons he thinks cinches the case for the moral superiority of high intelligence.

But it’s not even a good reason to think that. For a man who is constantly pounding his chest in honor of “empirical evidence”, he never seems to leave any room for that evidence when making claims such as this one. For anyone who has read any serious history on ancient greek society and politics, it should be obvious: there is absolutely no evidence to suggest that the founders of Greek democracy were “less intelligent” than their social peers. What’s more, far from being incompetent writers and orators, the Athenians were some of the most accomplished writers and orators in the Hellenistic world. It’s precisely because of how accomplished they were, that *we can talk about them at all, now*. In other words, *the evidence* stands in direct opposition to this claim. And he doesn’t seem to notice.

This is a problem throughout this book. There really is no good reason for the inclusion of the brief line of “reasoning” within which this claim is couched. It’s arbitrary and random. It neither sustains his primary claim – that reasoned debate is essential to stable civilizations – nor offers a challenge to it that he can respond to. In fact, it’s such an outlandish and distracting empty assertion, that it damages his main case. It’s ***not an argument\***. There are other places where similar interruptions are not nearly as damaging (such as the parenthetical mention of “abduction” at the end of his explication of induction and deduction). Which leads me to believe this book probably would have really benefited from a good editor.

### Consequences And Principles

The last example may seem too subtle for some. But I raise the objection here, because I think it’s important to point out that Stefan claims the mantle of a “public intellectual”, and has been, ostensibly, hard at work as an “internet philosopher” for at least 10 years. Why is this important? Because lay-people who read this book will take the misreadings as more-or-less correct, and find themselves with their pants down, when faced with someone who knows better. In particular, I’m referring to his mischaracterization of Consequentialism, as a ‘pragmatic’ (meaning ‘unprincipled’) doctrine:

> Atheists also tend to prefer consequentialism, or outcome-based moral standards. That which produces direct and immediate benefits in society is considered the good: the greatest good for the greatest number, and so on. These are not principled arguments, but pragmatic arguments. The principled argument against the welfare state is that it violates property rights (thou shalt not steal). The consequentialist argument for the welfare state is that it immediately reduces the amount of poverty in society. If your goal is consequentialist, principled arguments often stand in your way.

I am certainly no fan of consequentialist ethics, as readers of this blog will know. But to simply dismiss the theory out of hand as “unprincipled” or “pragmatic” is a weak approach at best. Mainly, because *consequentialism is not unprincipled*. Since Stefan has made indirect reference to Mill’s Greatest Happiness principle, I will then let Bentham and Mill speak for themselves:

> Nature has placed mankind under the governance of two sovereign masters, pain and pleasure. It is for them alone to point out what we ought to do, as well as to determine what we shall do. On the one hand the standard of right and wrong, on the other the chain of causes and effects, are fastened to their throne. They govern us in all we do, in all we say, in all we think: every effort we can make to throw off our subjection, will serve but to demonstrate and confirm it. In words a man may pretend to abjure their empire: but in reality he will remain subject to it all the while. The principle of utility recognizes this subjection, and assumes it for the foundation of that system, the object of which is to rear the fabric of felicity by the hands of reason and of law. Systems which attempt to question it, deal in sounds instead of sense, in caprice instead of reason… By the principle of utility is meant that principle which approves or disapproves of every action whatsoever according to the tendency it appears to have to augment or diminish the happiness of the party whose interest is in question: or, what is the same thing in other words to promote or to oppose that happiness. (Jeremy Bentham, Introduction to the Principles of Morals and Legislation)

And:

> The creed which accepts as the foundation of morals, Utility, or the Greatest Happiness Principle, holds that actions are right in proportion as they tend to promote happiness, wrong as they tend to produce the reverse of happiness. By happiness is intended pleasure, and the absence of pain; by unhappiness, pain, and the privation of pleasure. To give a clear view of the moral standard set up by the theory, much more requires to be said; in particular what things it includes in the ideas of pain and pleasure; and to what extent this is left an open question. But these supplementary explanations do not affect the theory of life on which this theory of morality is grounded— namely, that pleasure, and freedom from pain, are the only things desirable as ends; and that all desirable things (which are as numerous in the utilitarian as in any other scheme) are desirable either for the pleasure inherent in themselves, or as means to the promotion of pleasure and the prevention of pain. (JS Mill, Utilitarianism)

Now, it is certainly reasonable to question the correctness of this principle. For example, why is happiness directly equated with pleasure? Or, how do you address the objections in the Protagoras? Or any number of other complaints I, and other more skilled philosophers have raised in this blog and elsewhere. The Utility Principle is notorious for its myriad problems. But, *not being a principle* is not one of them. Perhaps Stefan should have taken the time to give us a definition of “principle” before proceeding with a condemnation of consequentialism as “unprincipled”.

Later on, he tries to extend the meaning of consequentialism itself, in order to heap more scorn on it:

> As the influence of women in society has grown, so has pragmatism, which can also be called consequentialism, which is the idea that an argument can be judged by its effects. If the effects are negative, The Argument is “problematic” or “inappropriate” or “offensive.”

Here, he is attempting to equate the fallacy of *[appeal to consequences](https://www.logicallyfallacious.com/tools/lp/Bo/LogicalFallacies/26/Appeal-to-Consequences)* with the moral theory of consequentialism. This is a profound category error. He lays blame for the fallacy of the appeal to consequences almost entirely at the feet of women (which also includes the only research paper he quotes – but doesn’t cite – in the entire book). But, setting that silliness aside (yet another distraction), he fails to provide an explanation for how consequentialism as a moral theory says incorrectly that propositions can be judged true or false as a result of the desirability of their effects. In this small, but incredibly disingenuous two-sentence passage, he’s managed to throw pragmatism, consequentialism, women, and ***The Argument\*** under the bus.

### Summary Conclusion (My Amazon Review)

I yearned for this to be a better book than it was. I sympathize with the sentiment that reason is beleaguered in modern society, and crave a good book on the topic. Alas, this is not the book. For all his railing against sophistry, confirmation bias, and appeals to emotion, Stefan relies heavily on an audience so steeped in its own prejudices, that it won’t notice the factual errors, logical incongruities, or interpretational biases littered throughout its pages. What’s worse, is that Molyneux attacks the disingenuous debater so strenuously in this book, that he often ends up recriminating himself for his own sloppiness.

Molyneux’s book reads like a personal journal that was transcribed directly into print. It is haphazard, overwrought, and at times, stream-of-consciousness. If you’re not already familiar with the lingo of internet Libertarianism, you’ll be completely confused by numerous passages. If you’re not already rehearsed in, and in agreement with, the arguments and positions of right-leaning anarchism (“anarcho-capitalism”), you’ll find the presumption of foregone conclusions scattered throughout the book to be irritating at best.

At bottom, the main problem with this book, is that it doesn’t appear to have an audience. The dismissive and sneering tone taken toward the political left will put them off. The appeals to the political right will (and has) earned him podcast interviews, but they certainly aren’t interested in philosophical inquiry beyond their own prejudices. The academic community has already shunned him as a lightweight at best, crackpot at worst. The book is too polemical and doctrinaire to appeal to the mainstream (many of whom fear him as some sort of cult leader already). So, who is this book for?

He will say, of course, that it is for the ‘true philosophers’. But any true philosopher will find this book terribly disappointing at best, perniciously self-defeating at worst. His explication of logic is amateur and incomplete, and at times just plain wrong. He takes Popperian falsificationism as a given, as if it were just a fact. He makes a sophomoric straw man of consequentialism, misreads Hume, offers only common-sense intuition explanations for complex topics like virtue and happiness, and deftly shifts from normative to descriptive usages of “right” and “wrong”, where it suits him.

In the end, as near as I can tell, the audience for this book was himself, and the handful who share whatever psychology it is that produced this work. The only person who will be most convinced by this work, is his own faltering conscience. He is defending heavily against the anxiety of uncertainty; the vulnerability and insecurity of having more questions than answers – and nowhere to look for them.

For centuries, the medievals also sought the same security in the reified power of deductive logic which Stefan is groping so desperately for in this book. On that count, I surely sympathize with him. The seduction of certainty – its comforting, self-soothing lullaby of finality and the archimedean lever it offers against those who would use doubt and curiosity to hurt, to plunder, and to oppress, is something I have been drawn to at times in my own life.

But for those of us afflicted by the daemon of Socrates, these islands of comfortable absolutism will never make a permanent home. Eventually, the urge to set sail again on the sea of uncertainty – on the path to discovery – will overtake the fear of being unmoored, and away we will voyage, come what may.

Stefan’s book is one such island of comfortable certitude, for some. The philosophers may visit, but they won’t stay long. What concerns me, though, are those who end up shipwrecked on one of these islands, before they’ve even had an opportunity to understand the voyage they set themselves on.

I will close this review with a few quotes from Stefan, that I would like to offer as chastening advice to Stefan himself:

> There are only two ways to achieve certainty: dogma and philosophy. Dogma is by far the easiest choice, of course, and while it may give you the illusion of certainty, it does not give you the reality of knowledge. Dogma arises, like most dysfunctions, from a greed for the unearned…
>
> If **The Argument** begins with the conclusion, it is neither an argument, nor a proof of any kind…

Indeed.

### Addendum: Making Stefan’s Case For Him

In researching for this review, I stumbled across [this review](https://medium.com/@alexanderdouglas/the-art-of-the-ego-review-of-stefan-molyneuxs-stupid-book-4a195ab1a5bc) of the book, by Alexander Douglas, a philosophy lecturer at St. Andrews in Scotland. On reading this review, I couldn’t help but cringe. Dr. Douglas has volunteered to make himself into precisely the boogy-man that Stefan points to as an example of why he’s so right, and everyone else is so wrong. As he says: “*When the debate is lost, slander becomes the tool of the loser*”.

If you are a professional philosopher, and you think Stefan Molyneux is not worth wasting a single breath on, then why write a “review” like this? Why acknowledge him at all? He’s not a professional philosopher, and only on the periphery of the political debate online, which itself, is already a periphery. If you *do* think he’s [worth the effort to review honestly](https://medium.com/@cianchartier/a-review-of-stefan-molyneuxs-the-art-of-the-argument-2c1c83fa7802), then why this sort of silly screed, that only serves to entrench his fans, and (as they would put it) “virtue signal” to yours? Why fall into this trap at all?

This is one of the reasons I decided to proceed with this review (I considered abandoning it several times). There needs to be somebody reviewing Stefan Molyneux in an honest way, with rigor and discipline, who doesn’t have an axe to grind. People hovering in the orbits around the personalities of the “internet right”, need to be able to find genuine criticism, in order to be able to make rational decisions themselves. It’s the only way out of the morass.

```[Imported from exitingthecave.com on 30 November 2021]```

