---
title: "Plato, Freud, Orwell, and the Danger of the Modern Mind"
date: 2017-07-18T23:42:27Z
tags: ["the soul","moral psychology","virtue"]
topics: ["philosophy","psychology","culture"]
image: /img/platos-soul.jpg
draft: false
---

In The Phaedrus, Plato offers up two rapturously beautiful visions of the soul of man. The first, is the Manichaean winged being of pure beauty, trapped against its will in a prison of corporeal form, and able to find relief only in the apprehension and achievement of true love. The second is a famous metaphor who’s hold on the modern mind is as ubiquitous as it is distorted and tragic.

Plato divides the soul up into three parts by likening it to a charioteer driving a chariot with two very head-strong steeds. It may be tempting to think of the charioteer as predominating in the relationship from the start, since he is the driver. But Plato describes a relation in which the charioteer is as much dependent upon his steeds, as they are subject to his admonitions. Nonetheless, he does also describe a process of perfection, whereby the charioteer brings the horses to heel, in pursuit of heavenly bliss. So it is likely that Plato imagined a process of maturation; one in which, though initially equal, the charioteer ought to end up the dominant member of the trio, reliant upon his horses only insofar as they are able to work in concert with him to reach the vault of heaven.

This is especially interesting, when we examine the nature of the steeds. According to Plato, one is ‘noble’, the other ‘ignoble’. The ‘noble’ steed, whose coat is pure white, is a representative of moral courage and a natural guide to heaven. The ‘ignoble’ steed, on the other hand, has a black coat and is disfigured and ill-tempered. It represents animal nature, carnal desires, and rage, and leads the chariot naturally to earth. The white steed will obey the charioteer’s instructions without the whip, only insofar as the charioteer is driving toward the good; the black horse rebels against all commands, regardless of direction — until it is beaten into submission.

Clearly, Plato is describing a struggle between the moral conscience and the biological urges in every normal human being. But, to borrow a concept from Freud, Plato seems to want to equate the ego with the moral conscience (or, at least, equate their separate intentions, more so than with the black horse). This equation will figure heavily on the remainder of this exploration.

Speaking of Freud, it cannot be an accident that his own theory of consciousness is tripartite, and of roughly the same character in its various parts. Freud hypothesizes an ‘id’, and a ‘super-ego’, as the analogues of the black and white horses. As I have already mentioned, he also hypothesizes an ‘ego’, that must negotiate between them. But, unlike Plato, Freud’s ego is not a charioteer. It doesn’t seem to be an equal partner at all, and often is depicted as far less vigorous than either of the two horses. At best, the ego is described as a rider on horseback, but who’s horse is ready to throw him at the first sign of disagreement. In fact, late in his book ‘The Ego and The Id’, the ego is depicted quite literally as an impotent “go-between”, tortured on one side by the dark terrors lurking in the black depths of the id, and on the other by the constant overbearing threat of recrimination and punishment from the all-seeing eye of the super-ego. To be fair, Freud was describing what he considered to be the pathological cases, in order to highlight the roles of each of the three aspects of consciousness, but it is not at all clear from his writing where the boundary between normalcy and pathology can be drawn. What’s more, he never takes the time in any of his other writings (as far as I am aware) to describe the “healthy” case, even in outline, and this has led most lay-people to take his hypothesis of pathology as representative of all psychology.

In any case, Freud’s model places the id in the dominant position in the partnership trio, acting as an inscrutable black box brimming with primitive passions, desires, and needs, about which the ego is almost helpless to do anything. As each of these things comes bubbling out of the cauldron of the id, the ego is tasked with either satisfying them as best it can, or repressing them, depending on what it learns from the super-ego. The super-ego, then (a representative of fatherly reproach) is far from a noble horse. It acts more-or-less as a negative reinforcement mechanism, punishing the ego for satisfying when it should have repressed, or repressing when it should have satisfied.

Freud’s general model is still quite fashionable today, because of its implicit determinism, and the superficial escape from responsibility this seems to offer us. The language of his theories permeates the culture: ego, id, libido, sex-drive, and so on. Very much the same way that Plato’s conceptual model of the soul permeates Freud’s theory. It is quite remarkable to me, just how inescapably pervasive are the ideas of some philosophers, informing our interpretation of the world, and even shaping the way in which we experience that world, from thousands of years in the past.

One modern author who’s work seems touched by just such an unconscious awareness, is the unlikely prophet, George Orwell. At first glance, his novel Nineteen Eighty-Four looks like a typical dystopian future science fiction. But a closer inspection reveals a very Freudian psychological drama unfolding with horrifying and tragic consequences. Orwell, whether he realized it or not, was warning that we unseat the charioteer at our own peril.

The novel opens by giving us a glimpse of a world completely dominated and oppressed by a super-ego so over-active and so ubiquitous, that there is nowhere and nothing that it cannot reach — and cannot punish. Yet, in spite of this, a weak but still yearning ego somehow manages to escape view (or so it believes) in one tiny dark corner of its only private space. This ego, interestingly enough, is tasked with the professional work of the destruction of its own history, and the continuous reinvention of a moving present in which the super-ego is the supreme ruler and judge of all. A present the ego desperately (and secretly) wishes to escape.

For Plato, the white horse represents the moral conscience, just like the super-ego. But the white horse was also a representative of the aspiration to ultimate truth and beauty – the route to the vault of heaven. Plato’s depiction of this horse is one of stoic stoutness, not tyrannical obstinacy. In fact, it is the black horse that is depicted as the obstinate one. So, how is it that Orwell’s white steed is distorted into such a monster (in the form of Big Brother)? By way of Freud. In The Ego and the Id, Freud describes a process whereby the id and the super-ego work together as a kind of tag-team, taking turns tempting and then punishing the frail ego, particularly in cases of deep melancholia or obsessional neurosis. This can become so severe in melancholia cases, that the ‘death instinct’ and the ‘life [sex] instinct’ become virtually fused in the psyche, resulting in the literal death of the ego, and the actual death of the patient.

These observations should be ringing a few bells, if you’ve read your Orwell. Lacking any proper guide in the form of his own white horse, the hapless ego – Winston – stumbles about in the gray universe of The Party, hoping to somehow find the kind of true love Plato orates for us in the Phaedrus. But, instead, he tragically mistakes the ecstasy of satisfying long deprived carnal pleasures for the attainment of just that true love, in the consummation of his relationship with Julia. Julia – the representative of Winston’s id – turns out to be precisely the kind of vicious collaborator Freud depicted in the obsessional neurotic. The white horse and the black horse are merged into an unnatural chimera of self-annihilation, and Winston his handed over to Big Brother. The despair proves to be too much, and he is doomed finally to the death of his true self – his soul, as Plato no doubt would have put it.

The genius of Plato was both in recognizing the reality of these competing features of the human psyche, and in realizing that ultimately it is the rational portion that must stand apart from the horses and act as the ‘guardian’ of the entire self, rather than the hopelessly inadequate servant to the fractious elements, competing for its efforts. The genius of Orwell, whether he quite knew it or not, was in recognizing that modern man had surrendered responsibility for the charioteer by embracing men like Skinner and Freud, and that nothing good would ever come of it.
